@@ -39,8 +39,10 @@ hashtag_changesets = {}
 countries_changesets = {}
 
 # read the GeoJSON file
-working_dir = os.path.realpath(os.getcwd())
-countries_df = gpd.read_file(os.path.join(working_dir, "data/countries_un.geojson"))
+working_dir = os.path.realpath(os.path.dirname(__file__))
+countries_df = gpd.read_file(
+    os.path.join(working_dir, "..", "data/countries_un.geojson")
+)
 
 
 def collect_changefile_stats(user, uname, changeset, version, tags, osm_type):
